Summary:	C++ standard library targeting C++11
Name:		libcxx
Version:	16.0.6
Release:	1%{?dist}
%global         libcxx_srcdir libcxx-%{version}.src
%global         libcxxabi_srcdir libcxxabi-%{version}.src
%global         libunwind_srcdir libunwind-%{version}.src
%global         maj_ver %(echo %{version} | cut -d. -f1)
License:	Apache-2.0 WITH LLVM-exception OR MIT OR NCSA
URL:		http://libcxx.llvm.org/
Source0:        https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/%{libcxx_srcdir}.tar.xz
Source1:        https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/%{libcxxabi_srcdir}.tar.xz
Source2:        https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/%{libunwind_srcdir}.tar.xz
Source3:	CMakeLists.txt

BuildRequires:	clang llvm-devel llvm-cmake-utils cmake ninja-build gnupg2
BuildRequires:	python3-devel

Requires: libcxxabi = %{version}-%{release}

%description
libc++ is a new implementation of the C++ standard library, targeting C++11.

%package devel
Summary:	Headers and libraries for libcxx devel
Requires:	%{name} = %{version}-%{release}
Requires:	libcxxabi-devel

%description devel
%{summary}.

%package static
Summary:	Static libraries for libcxx

%description static
%{summary}.

%package -n libcxxabi
Summary:	Low level support for a standard C++ library

%description -n libcxxabi
libcxxabi provides low level support for a standard C++ library.

%package -n libcxxabi-devel
Summary:	Headers and libraries for libcxxabi devel
Requires:	libcxxabi = %{version}-%{release}

%description -n libcxxabi-devel
%{summary}.

%package -n libcxxabi-static
Summary:	Static libraries for libcxxabi

%description -n libcxxabi-static
%{summary}.

%package -n llvm-libunwind
Summary:    LLVM libunwind

%description -n llvm-libunwind

LLVM libunwind is an implementation of the interface defined by the HP libunwind
project. It was contributed Apple as a way to enable clang++ to port to
platforms that do not have a system unwinder. It is intended to be a small and
fast implementation of the ABI, leaving off some features of HP's libunwind
that never materialized (e.g. remote unwinding).

%package -n llvm-libunwind-devel
Summary:    LLVM libunwind development files
Provides:   libunwind(major) = %{maj_ver}
Requires:   llvm-libunwind = %{version}-%{release}

%description -n llvm-libunwind-devel
Unversioned shared library for LLVM libunwind

%package -n llvm-libunwind-static
Summary: Static library for LLVM libunwind

%description -n llvm-libunwind-static
%{summary}.

%prep
%setup -T -q -b 0 -n %{libcxx_srcdir}
%setup -T -q -b 1 -n %{libcxxabi_srcdir}
%setup -T -q -b 2 -n %{libunwind_srcdir}
%setup -T -c -n build

cp %{SOURCE3} .
mv ../%{libcxx_srcdir} libcxx
mv ../%{libcxxabi_srcdir} libcxxabi
mv ../%{libunwind_srcdir} libunwind
%autopatch -p1

%py3_shebang_fix libcxx/utils/

%build
export ASMFLAGS=$CFLAGS

%cmake -GNinja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_MODULE_PATH="%{_libdir}/cmake/llvm;%{_datadir}/llvm/cmake/Modules" \
	-DCMAKE_POSITION_INDEPENDENT_CODE=ON \
	-DLIBCXX_LIBDIR_SUFFIX:STRING=64 \
	-DLIBCXXABI_LIBDIR_SUFFIX:STRING=64 \
	-DLIBUNWIND_LIBDIR_SUFFIX:STRING=64 \
	-DLIBCXX_INCLUDE_BENCHMARKS=OFF \
	-DLIBCXX_STATICALLY_LINK_ABI_IN_STATIC_LIBRARY=ON \
	-DLIBCXX_ENABLE_ABI_LINKER_SCRIPT=ON \
	-DLIBUNWIND_INSTALL_INCLUDE_DIR=%{_includedir}/llvm-libunwind \

%cmake_build

%install
%cmake_install

rm %{buildroot}%{_libdir}/libunwind.so
mkdir -p %{buildroot}/%{_libdir}/llvm-unwind/

pushd %{buildroot}/%{_libdir}/llvm-unwind
ln -s ../libunwind.so.1.0 libunwind.so
popd

%files
%license libcxx/LICENSE.TXT
%doc libcxx/CREDITS.TXT libcxx/TODO.TXT
%{_libdir}/libc++.so.*

%files devel
%{_includedir}/c++/
%exclude %{_includedir}/c++/v1/cxxabi.h
%exclude %{_includedir}/c++/v1/__cxxabi_config.h
%{_libdir}/libc++.so

%files static
%license libcxx/LICENSE.TXT
%{_libdir}/libc++.a
%{_libdir}/libc++experimental.a

%files -n libcxxabi
%license libcxxabi/LICENSE.TXT
%doc libcxxabi/CREDITS.TXT
%{_libdir}/libc++abi.so.*

%files -n libcxxabi-devel
%{_includedir}/c++/v1/cxxabi.h
%{_includedir}/c++/v1/__cxxabi_config.h
%{_libdir}/libc++abi.so

%files -n libcxxabi-static
%{_libdir}/libc++abi.a

%files -n llvm-libunwind
%license libunwind/LICENSE.TXT
%{_libdir}/libunwind.so.1
%{_libdir}/libunwind.so.1.0

%files -n llvm-libunwind-devel
%{_includedir}/llvm-libunwind/__libunwind_config.h
%{_includedir}/llvm-libunwind/libunwind.h
%{_includedir}/llvm-libunwind/libunwind.modulemap
%{_includedir}/llvm-libunwind/mach-o/compact_unwind_encoding.h
%{_includedir}/llvm-libunwind/mach-o/compact_unwind_encoding.modulemap
%{_includedir}/llvm-libunwind/unwind.h
%{_includedir}/llvm-libunwind/unwind_arm_ehabi.h
%{_includedir}/llvm-libunwind/unwind_itanium.h
%dir %{_libdir}/llvm-unwind
%{_libdir}/llvm-unwind/libunwind.so

%files -n llvm-libunwind-static
%{_libdir}/libunwind.a

%changelog
* Thu Sep 07 2023 kianli <kianli@tencent.com> - 16.0.6-1
- Initial build
